==> bulletinHD-2.1.zip: xoops_trust_path/modules/bulletin/language/spanish/main.php <==
<?php /* Spanish Translation by Marcelo Yuji Himoro <http://yuji.ws> */

if( defined( 'FOR_XOOPS_LANG_CHECKER' ) || ! defined( 'BULLETIN_MB_LOADED' ) ) {


// Appended by Xoops Language Checker -GIJOE- in 2007-05-08 12:57:29
define('_MD_TOPIC_IMAGE','Category image');
define('_MD_TOPIC_DISABLE','Do not display category icon');
define('_MD_TOPIC_LEFT','Display category icon on left side');
define('_MD_TOPIC_RIGHT','Display category icon on right side');
define('_MD_PUBINHOME','Publish on the index page');
define('_MD_PUBLISHED','Posted date');
define('_MD_EXPIRED','Expired');
define('_MD_SETDATETIME','Set the publication time');
define('_MD_SETDATETIME_DESC','* If you do not check it, published time will be current time.');
define('_MD_SETEXPDATETIME','Set expiration time');
define('_MD_SETEXPDATETIME_DESC','* If you do not check it, expired setting will become invalid.');
define('_MD_APPROVE','Approve this story');
define('_MD_DATE_FORMAT','%d %m %y %h : %i : %s');
define('_MD_DBPUDATED','Database updated successfully!');
define('_MD_POSTEDBY','Poster');
define('_MD_RELATION','Related articles');
define('_MD_ADD_RELATION','Add related articles');
define('_MD_CHECKED_AS_RELATION','Add as related articles');
define('_MD_DISP_BLOCK','Display on block');
define('_MD_RUSUREDEL','Are you sure you want to delete this news and all its comments?');
define('_MD_EMPTYNODELETE','Unable to delete.');
define('_MD_ARCHIVES','Archive');

define( 'BULLETIN_MB_LOADED' , 1 ) ;

//%%%%%%		File Name index.php 		%%%%%
define("_MD_PRINTER","Pgina de impresin");
define("_MD_SENDSTORY","Enviar esta noticia a un amigo");
define("_MD_READMORE","Seguir leyendo...");
define("_MD_COMMENTS","0 comentarios");
define("_MD_ONECOMMENT","1 comentario");
define("_MD_BYTESMORE","%s bytes restantes");
define("_MD_NUMCOMMENTS","%s comentarios");

//%%%%%%		File Name submit.php		%%%%%
define("_MD_SUBMITNEWS","Enviar noticia");
define("_MD_TITLE","Asunto");
define("_MD_TOPIC","Categora");
define("_MD_THESCOOP","Texto");
define("_MD_NOTIFYPUBLISH","Notificarme cuando se aprobe esta noticia");
define("_MD_POST","Publicar");
define("_MD_GO","Enviar");
define("_MD_THANKS","Hemos recebido tu envo. Espera a que el equipo del stio lo apruebe y lo publique definitivamente."); //submission of news article
// Added 2.0.11jp
define("_MD_THANKS_AUTOAPPROVE", "Gracias por tu envo.");

define("_MD_NOTIFYSBJCT","NOTICIAS en mi stio"); // Notification mail subject
define("_MD_NOTIFYMSG","Una nueva noticia ha sido enviada."); // Notification mail message

//%%%%%%		File Name archive.php		%%%%%
define("_MD_NEWSARCHIVES","Archivo de noticias");
define("_MD_ARTICLES","Noticias");
define("_MD_VIEWS","hits");
define("_MD_DATE","Fecha de envo");
define("_MD_ACTIONS","");
define("_MD_PRINTERFRIENDLY","Pgina de impresin");
define("_MD_THEREAREINTOTAL","Hay un total de %s noticias.");

// %s is your site name
define("_MD_INTARTICLE","Una interesante noticia que encontr en %s");
define("_MD_INTARTFOUND","Abajo tienes una noticia muy interesante que encontr en %s:");

define("_MD_TOPICC","Categora:");
define("_MD_URL","Direccin:");
define("_MD_NOSTORY","La noticia seleccionada no existe.");

//%%%%%%	File Name print.php 	%%%%%

define("_MD_URLFORSTORY","Direccin para esta noticia:");

// %s represents your site name
define("_MD_THISCOMESFROM","Puedes leer ms noticias desde %s.");

// Added language definitions for news expiry date
define("_AM_EXPARTS","Noticias expiradas");
define("_AM_EXPIRED","Expirado");
define("_AM_CHANGEEXPDATETIME","Cambiar fecha de validez");
define("_AM_SETEXPDATETIME","Definir fecha de validez");
define("_AM_NOWSETEXPTIME","Fecha de validez actual: %s");

// Added by suin
define("_MD_YEAR_X","%s");
define("_MD_NO_ARCIVES","No hay archivos.");
define("_MD_THANKS_BUT_ERROR", "Gracias por tu envo. Sin embargo, debido a un <span style=\"color:red\">error</span> no se ha publicado su noticia. Perdona por las molestias, y contacta a un administrador.");
define("_MD_USE_HTML","Activar HTML");
define("_MD_USE_SMILEY","Activar emoticones");
define("_MD_USE_BR","Activar salto de lnea automtico");
define("_MD_USE_XCODE","Activar Cdigo XOOPS");
define("_MD_JANUARY", "Enero");
define("_MD_FEBRUARY", "Febrero");
define("_MD_MARCH", "Marzo");
define("_MD_APRIL", "Abril");
define("_MD_MAY", "Mayo");
define("_MD_JUNE", "Junio");
define("_MD_JULY", "Julio");
define("_MD_AUGUST", "Agosto");
define("_MD_SEPTEMBER", "Septiembre");
define("_MD_OCTOBER", "Octubre");
define("_MD_NOVEMBER", "Noviembre");
define("_MD_DECEMBER", "Diciembre");
define("_MD_NO_TOPICS","No hay categoras.");

// ver 1.01 added
define("_MD_RSS", "RSS");

}
?>

==> bulletinHD-2.2.zip: xoops_trust_path/modules/bulletin/language/spanish/main.php <==
<?php /* Spanish Translation by Marcelo Yuji Himoro <http://yuji.ws> */

if( defined( 'FOR_XOOPS_LANG_CHECKER' ) || ! defined( 'BULLETIN_MB_LOADED' ) ) {



// Appended by Xoops Language Checker -GIJOE- in 2009-08-26 16:24:56
define('_MD_INPUTHELPER','Input Helper ON/OFF');
define('_MD_FCKXOOPS_ONOFF','FCK Editor ON/OFF (Note: Each of editors don&#039;t share the text)');
define('_MD_ERROR_REQUIRED','{0} is a required field.');

// Appended by Xoops Language Checker -GIJOE- in 2007-05-08 12:57:29
define('_MD_TOPIC_IMAGE','Category image');
define('_MD_TOPIC_DISABLE','Do not display category icon');
define('_MD_TOPIC_LEFT','Display category icon on left side');
define('_MD_TOPIC_RIGHT','Display category icon on right side');
define('_MD_PUBINHOME','Publish on the index page');
define('_MD_PUBLISHED','Posted date');
define('_MD_EXPIRED','Expired');
define('_MD_SETDATETIME','Set the publication time');
define('_MD_SETDATETIME_DESC','* If you do not check it, published time will be current time.');
define('_MD_SETEXPDATETIME','Set expiration time');
define('_MD_SETEXPDATETIME_DESC','* If you do not check it, expired setting will become invalid.');
define('_MD_APPROVE','Approve this story');
define('_MD_DATE_FORMAT','%d %m %y %h : %i : %s');
define('_MD_DBPUDATED','Database updated successfully!');
define('_MD_POSTEDBY','Poster');
define('_MD_RELATION','Related articles');
define('_MD_ADD_RELATION','Add related articles');
define('_MD_CHECKED_AS_RELATION','Add as related articles');
define('_MD_DISP_BLOCK','Display on block');
define('_MD_RUSUREDEL','Are you sure you want to delete this news and all its comments?');
define('_MD_EMPTYNODELETE','Unable to delete.');
define('_MD_ARCHIVES','Archive');

define( 'BULLETIN_MB_LOADED' , 1 ) ;

//%%%%%%		File Name index.php 		%%%%%
define("_MD_PRINTER","Pgina de impresin");
define("_MD_SENDSTORY","Enviar esta noticia a un amigo");
define("_MD_READMORE","Seguir leyendo...");
define("_MD_COMMENTS","0 comentarios");
define("_MD_ONECOMMENT","1 comentario");
define("_MD_BYTESMORE","%s bytes restantes");
define("_MD_NUMCOMMENTS","%s comentarios");

//%%%%%%		File Name submit.php		%%%%%
define("_MD_SUBMITNEWS","Enviar noticia");
define("_MD_TITLE","Asunto");
define("_MD_TOPIC","Categora");
define("_MD_THESCOOP","Texto");
define("_MD_NOTIFYPUBLISH","Notificarme cuando se aprobe esta noticia");
define("_MD_POST","Publicar");
define("_MD_GO","Enviar");
define("_MD_THANKS","Hemos recebido tu envo. Espera a que el equipo del stio lo apruebe y lo publique definitivamente."); //submission of news article
// Added 2.0.11jp
define("_MD_THANKS_AUTOAPPROVE", "Gracias por tu envo.");

define("_MD_NOTIFYSBJCT","NOTICIAS en mi stio"); // Notification mail subject
define("_MD_NOTIFYMSG","Una nueva noticia ha sido enviada."); // Notification mail message

//%%%%%%		File Name archive.php		%%%%%
define("_MD_NEWSARCHIVES","Archivo de noticias");
define("_MD_ARTICLES","Noticias");
define("_MD_VIEWS","hits");
define("_MD_DATE","Fecha de envo");
define("_MD_ACTIONS","");
define("_MD_PRINTERFRIENDLY","Pgina de impresin");
define("_MD_THEREAREINTOTAL","Hay un total de %s noticias.");

// %s is your site name
define("_MD_INTARTICLE","Una interesante noticia que encontr en %s");
define("_MD_INTARTFOUND","Abajo tienes una noticia muy interesante que encontr en %s:");

define("_MD_TOPICC","Categora:");
define("_MD_URL","Direccin:");
define("_MD_NOSTORY","La noticia seleccionada no existe.");

//%%%%%%	File Name print.php 	%%%%%

define("_MD_URLFORSTORY","Direccin para esta noticia:");

// %s represents your site name
define("_MD_THISCOMESFROM","Puedes leer ms noticias desde %s.");

// Added language definitions for news expiry date
define("_AM_EXPARTS","Noticias expiradas");
define("_AM_EXPIRED","Expirado");
define("_AM_CHANGEEXPDATETIME","Cambiar fecha de validez");
define("_AM_SETEXPDATETIME","Definir fecha de validez");
define("_AM_NOWSETEXPTIME","Fecha de validez actual: %s");

// Added by suin
define("_MD_YEAR_X","%s");
define("_MD_NO_ARCIVES","No hay archivos.");
define("_MD_THANKS_BUT_ERROR", "Gracias por tu envo. Sin embargo, debido a un <span style=\"color:red\">error</span> no se ha publicado su noticia. Perdona por las molestias, y contacta a un administrador.");
define("_MD_USE_HTML","Activar HTML");
define("_MD_USE_SMILEY","Activar emoticones");
define("_MD_USE_BR","Activar salto de lnea automtico");
define("_MD_USE_XCODE","Activar Cdigo XOOPS");
define("_MD_JANUARY", "Enero");
define("_MD_FEBRUARY", "Febrero");
define("_MD_MARCH", "Marzo");
define("_MD_APRIL", "Abril");
define("_MD_MAY", "Mayo");
define("_MD_JUNE", "Junio");
define("_MD_JULY", "Julio");
define("_MD_AUGUST", "Agosto");
define("_MD_SEPTEMBER", "Septiembre");
define("_MD_OCTOBER", "Octubre");
define("_MD_NOVEMBER", "Noviembre");
define("_MD_DECEMBER", "Diciembre");
define("_MD_NO_TOPICS","No hay categoras.");

// ver 1.01 added
define("_MD_RSS", "RSS");

}
?>
